@@ -2,7 +2,7 @@
 (let ((warning #f))
     (d-GoToPosition 1 1 1 1)
     (if (not (EmptyMeasure?))
-        (if (d-SetSaved)
+        (if (d-GetSaved)
             (let ((choice (RadioBoxMenu (cons (_ "Remove All Music?") 'remove) (cons (_ "Keep Music?") 'keep))))
                 (case choice
                     ((remove)
@@ -10,7 +10,8 @@
                             (if (d-Directive-standalone? "DenemoLink")
                                 (begin
                                     (d-SetMark)
-                                    (d-Copy)))
+                                    (d-Copy))
+                                (d-ClearClipboard))
                             (d-DirectiveDelete-scoreheader "ScoreIncipit")
                             (d-DeleteFromCursorToEnd 'all)
                             (let loop () 
