@@ -5,10 +5,10 @@
       (begin
         (d-AddDot)
         (d-ToggleBeginSlur)
-        (eval-string (string-append "(d-" (number->string duration) ")"))
+        (eval-string (string-append "(d-" (number->string (+ 1 duration)) ")"))
         (d-MoveCursorLeft)
-        (d-Diminish)
         (d-ToggleEndSlur)
+        (d-PlayMidiNote 53 80 9 10)
         (if (and nonprinting (not (d-GetMarkedMidiNote)))
-        	(d-SetNonprinting))
+            (d-SetNonprinting))
         (d-MoveCursorRight)))))
