@@ -1,9 +1,12 @@
 ;;Breve
+(let ((appending (or (None?) (Appending?))))
 (d-0)
-(d-MoveCursorLeft)
-(d-ChangeBreve)
-(d-MoveCursorRight)
+(if (Appending?)
+    (d-MoveCursorLeft))
+(d-ChangeBreve);
 (if (and (defined? 'Snippet::Breve) (> Snippet::Breve 0))
     (d-SelectSnippet Snippet::Breve)
     (d-CreateSnippetFromObject "Breve"))
+  (if appending
+    (d-MoveCursorRight)))
 
