@@ -1,8 +1,12 @@
 ;;Longa
+(let ((appending (or (None?) (Appending?))))
 (d-0)
-(d-MoveCursorLeft)
+(if (Appending?)
+    (d-MoveCursorLeft))
 (d-ChangeLonga)
-(d-MoveCursorRight)
 (if (and (defined? 'Snippet::Longa) (> Snippet::Longa 0))
     (d-SelectSnippet Snippet::Longa)
     (d-CreateSnippetFromObject "Longa"))
+  (if appending
+    (d-MoveCursorRight)))
+
