@@ -1,5 +1,5 @@
 ;;;SubstituteMusic
-(let ((params SubstituteMusic::params)(tag "SubstituteMusic"))
+(let ((params SubstituteMusic::params)(tag "SubstituteMusic")(voice (d-IsVoice)))
         (if (and (not params)(d-Directive-voice? tag))
             (begin
                 (d-MoveToBeginning)
@@ -19,10 +19,13 @@
                         (d-PushPosition)
                         (while (d-MoveToStaffUp))
                         (let loop ((count 0))
-                            (set! voicenames (cons 
-                                (cons (unique-staff-name)  (cons  (unique-staff-name)
-                                          (cons (if (d-Directive-staff? "DynamicsStaff") "(d-DynamicsStaff 'noninteractive)" #f) (string-append "{" (d-GetPrevailingClefAsLilyPond)(d-GetPrevailingTimesigAsLilyPond)(d-GetPrevailingKeysigAsLilyPond) "\\" (d-GetVoiceIdentifier) " } \\void "))))
-                                                 voicenames))      
+                            (set! voicenames (cons
+                                (cons (unique-staff-name)  
+                                	(cons  (unique-staff-name)
+                                          (cons (if (d-Directive-staff? "DynamicsStaff") "(d-DynamicsStaff 'noninteractive)" #f) 
+                                          	(cons (string-append "{" (if voice "" (string-append (d-GetPrevailingClefAsLilyPond)(d-GetPrevailingTimesigAsLilyPond)(d-GetPrevailingKeysigAsLilyPond))) "\\" (d-GetVoiceIdentifier) " } \\void ")
+                                          	 (number->string (1+ count))))))
+                                                 	voicenames))
                             (if (d-MoveToStaffDown)
                                 (loop (1+ count))))
                         (d-PopPosition)
@@ -33,12 +36,15 @@
                     (begin
                         (d-WarningDialog (_ "There are no other staffs for this one to mirror.")))
                     (begin
-                        (set! cuename (RadioBoxMenuList cuename))
+                        (if (number? params)
+                            (set! cuename (cdr (list-ref cuename (1- params))))
+                            (set! cuename (RadioBoxMenuList cuename)))
                         (if cuename
                             (let ((dynamics-staff (cadr cuename)))
                                 (if dynamics-staff
                                     (eval-string dynamics-staff))
-                                (d-DirectivePut-voice-prefix tag (cddr cuename))    
+                                (d-DirectivePut-voice-prefix tag (caddr cuename))    
+                                (d-DirectivePut-voice-data tag (cdddr cuename))
                                 (d-DirectivePut-voice-override tag  (logior DENEMO_ALT_OVERRIDE DENEMO_OVERRIDE_GRAPHIC))
                                 (d-DirectivePut-voice-display tag (car cuename))
                                 (d-SetColorOfStaff #xF0202000)
@@ -58,6 +64,4 @@
                                 (d-DirectivePut-standalone-graphic tag (string-append "\n"
                                 (_ "Music here is mirrored from ") (d-DirectiveGet-voice-display tag) "\nDenemo\n20"))
                                 ;;;(d-ToggleCurrentStaffDisplay) dynamics staffs don't display well when hidden
-                                (d-SetSaved #f))))))))
-
-
+                                (d-SetSaved #f))))))))          
