@@ -8,13 +8,7 @@
 (if (StemDirective?) (d-DeleteObject) (set! move-right #t))
 (d-StartUpStems)
 (d-MoveCursorLeft)
-(d-DirectivePut-stemdirective-graphic tag "
-v3
-Serif
-24
-1
-1")
 (d-PopPosition)
 (if move-right
   (d-MoveCursorRight));;to compensate for the insertion of the stem directive
-(d-SetSaved #f))
\ No newline at end of file
+(d-SetSaved #f))
