@@ -52,11 +52,11 @@ process_midi (PtTimestamp timestamp, void *user_data)
     }
 
   PmEvent event;
-
+  int r;
   while (Pm_Poll (input_stream) == TRUE)
     {
 
-      int r = Pm_Read (input_stream, &event, 1);
+      r = Pm_Read (input_stream, &event, 1);
 
       // we should only ever get one event.
       // if we get a sysex, just skip it.
@@ -109,7 +109,7 @@ portmidi_initialize (DenemoPrefs * config)
         {
           id = get_portmidi_device_id ("default", FALSE);
           info = Pm_GetDeviceInfo (id);
-           if (info == NULL)  
+           if (info == NULL)
                 {
                 g_warning ("No MIDI input device, and no default device");
                 portmidi_destroy ();
