@@ -103,27 +103,18 @@ dnm_addmeasures (DenemoMovement * si, gint pos, guint nummeasures, gint all)
   return addmeasures (si, pos, nummeasures, all);
 }
 
-/**
- * g_list_foreach function called by freeobjlist
- */
-static void
-freeit_object (gpointer data, gpointer user_data)
-{
-  freeobject ((DenemoObject *) data);
-}
 
 /**
  * Free a measures objects
  *
  */
 void
-freeobjlist (gpointer data)
+freeobjlist (objnode *delobjs)
 {
-  objnode *delobjs = (objnode *) data;
   if (delobjs)
     {
       /* Free all the Denemo objects */
-      g_list_foreach (delobjs, freeit_object, NULL);
+      g_list_foreach (delobjs, (GFunc) freeobject, NULL);
       /* Free the object list itself */
       g_list_free (delobjs);
     }
@@ -141,12 +132,9 @@ clone_measure (DenemoMeasure* m)
     return ret;
 }
 
-void
-free_measure (DenemoMeasure *m)
+void free_measure (DenemoMeasure *m)
 {
-  GList *g;
-   for (g=m->objects;g;g=g->next)
-     freeobjlist (g);
+  g_list_foreach (m->objects, (GFunc)freeobject, NULL);  
   m->objects = NULL;
 }
 /**
@@ -346,6 +334,7 @@ settickvalsinmeasure (objnode * theobjs)
 
       if (theobj->type == CHORD)
         {
+          chord *thechord = ((chord *) theobj->object);
           if (in_tuplet)
             {
               if (!((chord *) theobj->object)->is_grace)
@@ -354,11 +343,12 @@ settickvalsinmeasure (objnode * theobjs)
                   basic_ticks_in_tuplet_group += theobj->basic_durinticks;
                 }  else
                 {
+                    if (!(thechord->is_grace & DURATION_SET))
+                      theobj->durinticks = 0;
                     if(is_end_grace (curobjnode))
-                      ((chord *) theobj->object)->is_grace |= ENDGRACE;
+                      thechord->is_grace |= ENDGRACE;
                     else
-                      ((chord *) theobj->object)->is_grace &= (~ENDGRACE);    //and re-instate if needed
-                    theobj->durinticks = 0;
+                      thechord->is_grace &= (~ENDGRACE);    //and re-instate if needed
                 }
 
 
@@ -366,15 +356,16 @@ settickvalsinmeasure (objnode * theobjs)
           else
             {
 
-              ((chord *) theobj->object)->is_grace &= (GRACED_NOTE | ACCIACCATURA);     //leave any fixed grace, changed by toggle.
+              thechord->is_grace &= (GRACED_NOTE | ACCIACCATURA | DURATION_SET);     //leave any fixed grace, changed by toggle.
 
-              if (((chord *) theobj->object)->is_grace)
+              if (thechord->is_grace)
                 {
+                    if (!(thechord->is_grace & DURATION_SET))
+                      theobj->durinticks = 0;
                     if(is_end_grace (curobjnode))
-                      ((chord *) theobj->object)->is_grace |= ENDGRACE;
+                      thechord->is_grace |= ENDGRACE;
                     else
-                      ((chord *) theobj->object)->is_grace &= (~ENDGRACE);    //and re-instate if needed
-                    theobj->durinticks = 0;
+                      thechord->is_grace &= (~ENDGRACE);    //and re-instate if needed
                 }
               else
                 theobj->durinticks = theobj->basic_durinticks;
@@ -463,7 +454,7 @@ setsdir (objnode * starter, objnode * ender, gint beamgroup_sum, gint beamgroup_
       theobj = (DenemoObject *) curobjnode->data;
       if (theobj->type == CHORD)
         {
-          if ((((chord *) theobj->object)->baseduration <= 0))
+          if ((((chord *) theobj->object)->baseduration == 0) || (((chord *) theobj->object)->baseduration <-7))
             /* Whole notes are always laid out stemup */
             ((chord *) theobj->object)->is_stemup = TRUE;
           else
@@ -649,6 +640,10 @@ set_accidental_positions (DenemoObject * the_chord)
   gint i;
   chord chordval = *(chord *) the_chord->object;
   gint baseduration = chordval.baseduration;
+  if (baseduration<-7)
+    baseduration = 0;
+  if (baseduration < 0)
+    baseduration = -baseduration;
   if (g_list_length (chordval.notes) > ACCS_TOO_CLOSE)
     return;
 
