@@ -81,15 +81,17 @@ push_clipboard (void)
   clip->staffsinbuffer = staffsinbuffer;
   clipboards = g_list_prepend (clipboards, clip);
 }
-
+//takes the count'th stored clipboard and makes it the current clipboard
 gboolean
-pop_clipboard (void)
+pop_clipboard (gint count)
 {
   GList *thecopy = NULL;
   DenemoClipboard *clip;
   if (clipboards == NULL)
     return FALSE;
-  clip = (DenemoClipboard *) clipboards->data;
+  clip = (DenemoClipboard *) g_list_nth_data (clipboards, count);
+  if (!clip)
+    return FALSE;
   clipboards = g_list_remove (clipboards, clip);
   clearbuffer ();
   if (clip->objectlist)
@@ -158,7 +160,7 @@ free_clipboard (GList * clipboard)
       measurebreaksinbuffer = 0;
       staffsinbuffer = 1;
       clearbuffer ();
-      pop_clipboard ();
+      pop_clipboard (0);
     }
 }
 
@@ -179,41 +181,12 @@ insert_clipboard (GList * clipboard)
       staffsinbuffer = 1;
       call_out_to_guile ("(d-Paste)");
       copybuffer = NULL;
-      pop_clipboard ();
+      pop_clipboard (0);
       displayhelper (Denemo.project);
       score_status(Denemo.project, TRUE);
     }
 }
 
-/**
- *  saveselection
- *  Saves the current selection to a given file
- *
- *  @param si pointer to the score information structure
- *  @return none
- */
-void
-saveselection (DenemoMovement * si)
-{
-  if (si->markstaffnum == 0)    /* Indicator that there's no selection.  */
-    return;
-  clearbuffer ();
-
-  staffsinbuffer = si->selection.laststaffmarked - si->selection.firststaffmarked + 1;
-
-  copytobuffer (si);
-  si->savebuffer = copybuffer;
-  /* Test code for save selection
-     FILE *fp;
-     GString *file = NULL;
-     file = g_string_new(get_user_data_dir());
-     g_string_append(file, "/denemoanalysispattern");
-
-     filesaveselection(file->str, si);
-     clearbuffer ();
-     g_free(file);
-   */
-}
 
 /**
  *   copytobuffer
@@ -929,21 +902,6 @@ pastewrapper (DenemoAction * action, DenemoScriptParam * param)
 }
 
 
-/**
- * saveselwrapper
- * Wrapper function for the Save selection command
- *
- * @param action pointer to the DenemoAction event
- * @param gui pointer to the DenemoProject structure
- */
-void
-saveselwrapper (DenemoAction * action, DenemoScriptParam * param)
-{
-  DenemoProject *gui = Denemo.project;
-  saveselection (gui->movement);
-}
-
-
 /**
  * calcmarkboundaries
  * Wrapper function for the mark_boundaries_helper function
