@@ -1102,6 +1102,7 @@ newScrollPointsElem (xmlNodePtr curElem, xmlNsPtr ns, GList * scroll_points)
 /**
  * Export the given score (from measure start to measure end) as a "native"
  * Denemo XML file to the given file.
+ * returns 0 on success
  */
 gint
 exportXML (gchar * thefilename, DenemoProject * gui)
@@ -1137,7 +1138,7 @@ exportXML (gchar * thefilename, DenemoProject * gui)
   //xmlSetDocCompressMode (doc, XML_COMPRESSION_RATIO);
   //xmlSetCompressMode (Denemo.prefs.compression);
   xmlSetDocCompressMode (doc, Denemo.prefs.compression);
-  g_print ("Document compression mode set to %d, (read back as %d)\n", Denemo.prefs.compression, xmlGetDocCompressMode (doc));
+  //g_print ("Document compression mode set to %d, (read back as %d)\n", Denemo.prefs.compression, xmlGetDocCompressMode (doc));
   doc->xmlRootNode = scoreElem = xmlNewDocNode (doc, NULL, (xmlChar *) "score", NULL);
   ns = xmlNewNs (doc->xmlRootNode, (xmlChar *) DENEMO_XML_NAMESPACE, NULL);
   xmlSetProp (scoreElem, (xmlChar *) "version", (xmlChar *) version_string);
@@ -1236,7 +1237,10 @@ exportXML (gchar * thefilename, DenemoProject * gui)
         newXMLIntChild (parentElem, ns, (xmlChar *) "measure-width", si->measurewidth);
 
 
-
+      if (si->sketch)
+        {
+          newXMLIntChild (mvmntElem, ns, "sketch", 1);
+        }
 
       if (si->header.directives)
         {
