@@ -140,39 +140,13 @@ get_or_create_command(gchar* name){
   return command;
 }
 
-
-void
-dnm_clean_event (GdkEventKey * event)
-{ 
-  if (!Denemo.prefs.strictshortcuts)
-    {
-      guint ret = event->keyval;
-      if (ret >= 'A' && ret <= 'Z')
-        ret += ('a' - 'A');
-#ifdef G_OS_WIN32
-      else
-        if (event->hardware_keycode>47 && event->hardware_keycode<58)
-          {
-            ret = event->hardware_keycode;
-          }
-#else
-      else
-        if (event->hardware_keycode>9 && event->hardware_keycode<20)
-          {
-            ret = 39 + event->hardware_keycode;
-            if (ret==58)
-              ret = 48;
-          }
-#endif
-      event->keyval = ret;
-    }
-  //g_print("Hardware key %d Key val has been cleaned to %d -> %s\n", event->hardware_keycode, event->keyval, gdk_keyval_name(event->keyval));
-}
-
-
-/* Returns the state of the event after removing the modifiers consumed by the
- * system and unwanted modifiers. Use this before doing anything based on the
- * (keyval, state) pair in an event handler.
+/* If Denemo.prefs.strictshortcuts is set, returns the state of the event after
+ * removing the modifiers consumed by the system and unwanted modifiers.
+ * Otherwise, returns the group 0, level 0 value of the key according to GDK.
+ * That is, all uppercase ASCII letters modified by shift become lowercase, and
+ * all number keys stick to the first level (i.e., the number, not the symbol).
+ * Use this before doing anything based on the (keyval, state) pair in an event 
+ * handler.
  */
 guint
 dnm_sanitize_key_state (GdkEventKey * event)
@@ -180,10 +154,26 @@ dnm_sanitize_key_state (GdkEventKey * event)
   guint ret = event->state;
   if (!Denemo.prefs.strictshortcuts)
     {
-      return ret;
+	// Declare variables for GDK return
+	gint n_entries;
+	GdkKeymapKey * keys = NULL;
+	guint * keyvals = NULL;
+
+	// Pass the event's hardware_keycode into GDK and get all matching
+	// key values
+	if (gdk_keymap_get_entries_for_keycode (gdk_keymap_get_default (),
+		event->hardware_keycode, &keys, &keyvals, &n_entries))
+	{
+	    // Take the level 0 key value and store it back in the event
+	    event->keyval = keyvals[0];
+	    g_free(keys);
+	    g_free(keyvals);
+	}
+
+	// Return unmodified event->state
+        return ret;
     }
 
-#if 1
   GdkModifierType consumed;
   /* We want to ignore irrelevant modifiers like ScrollLock */
 
@@ -192,7 +182,7 @@ dnm_sanitize_key_state (GdkEventKey * event)
   ret &= ~consumed;
   /* removing other unwanted modifiers from event->state */
   ret &= (GDK_CONTROL_MASK | GDK_SHIFT_MASK | GDK_MOD1_MASK | GDK_MOD2_MASK | GDK_MOD3_MASK | GDK_MOD4_MASK | GDK_MOD5_MASK /*    these make numlock required to be off for example */ );
-#endif
+
   return ret;
 }
 
@@ -414,10 +404,9 @@ dnm_accelerator_name (guint accelerator_key, GdkModifierType accelerator_mods)
       name = g_string_new (gdk_keyval_name (accelerator_key));
       //g_print ("Keyval %d gdk name %s\n", accelerator_key, name->str);
       if (name->len > 3 && (*name->str == 'K') && (*(name->str + 1) == 'P') && (*(name->str + 2) == '_'))
-#ifndef G_OS_WIN32  
         {
-           if((*(name->str + 3) >='0') && (*(name->str + 3) <='6'))
-            g_string_erase (name, 0, 3);    //force numeric keypad KP_n names to normal except for 7 8 9 which are not needed for duration entry also ignore NumLock for these
+          if((*(name->str + 3) >='0') && (*(name->str + 3) <='6'))
+            g_string_erase (name, 0, 3);    //force numeric keypad KP_n names to normal number names except for 7 8 9 which are not needed for duration entry also ignore NumLock for these
           else if(!strcmp(name->str, "KP_Insert"))
                   g_string_assign (name, "0");
           else if(!strcmp(name->str, "KP_Delete"))
@@ -434,13 +423,14 @@ dnm_accelerator_name (guint accelerator_key, GdkModifierType accelerator_mods)
                   g_string_assign (name, "5");
           else if(!strcmp(name->str, "KP_Right"))
                   g_string_assign (name, "6");
+          else if(!strcmp(name->str, "KP_Home"))
+                  g_string_assign (name, "KP_7");
+          else if(!strcmp(name->str, "KP_Up"))
+                  g_string_assign (name, "KP_8");
+          else if(!strcmp(name->str, "KP_Page_Up"))
+                  g_string_assign (name, "KP_9");
         }
-#else
-        {
-          if((*(name->str + 3) !='7') && (*(name->str + 3) !='8') && (*(name->str + 3) !='9'))
-            g_string_erase (name, 0, 3);    //force numeric keypad KP_ names to normal except for 7 8 9 which are not needed for duration entry
-        }
-#endif
+
       //g_print("\ndnm_accelerator_name using gtk_accelerator_get label %s\n gdk_keyval_name name %s\n", gtk_accelerator_get_label(accelerator_key, 0), gdk_keyval_name(accelerator_key));
       //g_debug("mods were %x\n", accelerator_mods);
 #if 0
@@ -1326,18 +1316,23 @@ stolen_gtk_menu_stop_navigating_submenu (GtkMenu * menu)
 gint
 keymap_accel_quick_edit_snooper (GtkWidget * grab_widget, GdkEventKey * event, DenemoAction *action)
 {
+  gboolean ret = TRUE;
   guint keyval;
   GdkModifierType modifiers;
   keymap *the_keymap = Denemo.map;
   GtkMenu *menu = GTK_MENU (grab_widget);
+  //g_print ("Key val %x state %x\n", event->keyval, event->state);
   if ((event->keyval == 65481) && (event->state == 0)) //Fn12 hardwired to repeat last command
     {
       warningdialog (_("Fn12 is hard-wired to repeat the last command"));
       return FALSE;
     }
-  if (Denemo.prefs.menunavigation && ((event->keyval == 0xFF1B) || (event->keyval == 0xFF51) || (event->keyval == 0xFF52) || (event->keyval == 0xFF53) || (event->keyval == 0xFF54)))
+  if (Denemo.prefs.menunavigation)
     {
-//Esc and arrows for navigating menus
+	if (event->keyval == 0xFF0D)
+		ret = FALSE; //allow setting the Return shortcut *and* execute the command
+	//Esc and arrows for navigating menus
+	if ((event->keyval == 0xFF1B) || (event->keyval == 0xFF51) || (event->keyval == 0xFF52) || (event->keyval == 0xFF53) || (event->keyval == 0xFF54))
       return FALSE;
     }
 
@@ -1348,7 +1343,6 @@ keymap_accel_quick_edit_snooper (GtkWidget * grab_widget, GdkEventKey * event, D
   //If the KeyEvent is only a modifier, stop processing here
   if (isModifier (event))
     return TRUE;
-  dnm_clean_event (event);
   modifiers = dnm_sanitize_key_state (event);
   keyval = event->keyval;
 
@@ -1367,7 +1361,7 @@ keymap_accel_quick_edit_snooper (GtkWidget * grab_widget, GdkEventKey * event, D
 //#endif
   //Add the keybinding
   add_keybinding_to_idx (the_keymap, keyval, modifiers, idx, POS_FIRST);
-  return TRUE;
+  return ret;
 }
 
 
