@@ -49,7 +49,7 @@ static void set_default_lilypond_path (void)
  *
  */
 void
-initprefs ()
+initprefs (void)
 {
   gchar *dotdenemo = (gchar *) get_user_data_dir (TRUE);
   gchar *localrc = dotdenemo ? g_build_filename (dotdenemo, PREFS_FILE, NULL) : NULL;
@@ -83,7 +83,6 @@ initprefs ()
   set_default_lilypond_path ();
   ret->profile = g_string_new ("Default");
   ret->denemopath = g_string_new (g_get_home_dir ());
-  ret->lilyversion = g_string_new (""); //meaning use installed LilyPond version
   ret->temperament = g_string_new ("Equal");
   ret->strictshortcuts = FALSE;
   ret->resolution = 300;
@@ -102,6 +101,7 @@ initprefs ()
   ret->newbie = TRUE;
   ret->persistence = TRUE;
   ret->learning = TRUE;
+  ret->menunavigation = TRUE;
   ret->immediateplayback = TRUE;
   ret->measureswitchsound = 75;
   ret->manualtypeset = FALSE;
@@ -129,7 +129,7 @@ initprefs ()
   ret->portaudio_period_size = 256;
 
   ret->portmidi_input_device = g_string_new ("default");
-  ret->portmidi_output_device = g_string_new ("default");
+  ret->portmidi_output_device = g_string_new ("none");//Denemo has no code to output MIDI in real time, this turns off the setting up of the channel
 
   gchar *soundfontpath = find_denemo_file(DENEMO_DIR_SOUNDFONTS, "A320U.sf2");
 
@@ -168,25 +168,25 @@ initprefs ()
   ret->quickshortcuts = TRUE;
   ret->progressbardecorations = TRUE;
 
-  /* Read values from personal preferences file */
+ 
 
-  //readpreffile (localrc, ret);
- if (!Denemo.non_interactive)  if (localrc)
-    {
-      if (g_file_test (localrc, G_FILE_TEST_EXISTS))
-        readxmlprefsFile (localrc);
-      else
-        writeXMLPrefs (ret);
+ /* Read values from personal preferences file if any*/
+  if (localrc && g_file_test (localrc, G_FILE_TEST_EXISTS))
+	readxmlprefsFile (localrc);
+	
+  if(ret->lilypath && !g_file_test (ret->lilypath->str, G_FILE_TEST_EXISTS))
+	set_default_lilypond_path ();  
+	
+  Denemo.lilypond_installed_version = get_lily_version_string ();
+  Denemo.lilypond_include_dir = get_lilypond_include_dir ();
+  initialize_lilypond_includes();   
+  if (!Denemo.non_interactive)
+    {     
+     writeXMLPrefs (ret);
     }
   g_free (localrc);
-
-
- if (!Denemo.non_interactive)  if(ret->lilypath && !g_file_test (ret->lilypath->str, G_FILE_TEST_EXISTS))
-    set_default_lilypond_path ();
     //FIXME if ret->lilypath still does not exist prepare to issue warning to user once the GUI is available.
 #undef ret
-
-
 }
 
 
@@ -201,13 +201,13 @@ initprefs ()
 static void
 parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 {
-  cur = cur->xmlChildrenNode;
+  cur = cur->children;
   while (cur != NULL)
     {
 #define READXMLENTRY(field)  \
       else if (0 == xmlStrcmp (cur->name, (const xmlChar *) #field))\
     {\
-      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->children, 1);\
       if(tmp)\
         {\
               define_scheme_variable("DenemoPref_" #field, (gchar*) tmp, NULL);\
@@ -221,7 +221,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       else if (0 ==\
            xmlStrcmp (cur->name, (const xmlChar *) #field))\
     {\
-      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->children, 1);\
       if(tmp)\
         {\
               define_scheme_int_variable("DenemoPref_" #field, atoi((gchar *) tmp), NULL); \
@@ -234,7 +234,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       else if (0 ==\
            xmlStrcmp (cur->name, (const xmlChar *) #field))\
     {\
-      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->children, 1);\
       if(tmp)\
         {\
               define_scheme_int_variable("DenemoPref_" #field, atof((gchar *) tmp), NULL); \
@@ -248,7 +248,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       else if (0 ==\
            xmlStrcmp (cur->name, (const xmlChar *) #field))\
     {\
-      xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);\
+      xmlChar *tmp = xmlNodeListGetString (doc, cur->children, 1);\
       if(tmp)\
         {\
               define_scheme_bool_variable("DenemoPref_" #field, atoi((gchar *) tmp), NULL); \
@@ -262,7 +262,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 
       if (0 == xmlStrcmp (cur->name, (const xmlChar *) "lilypath"))
         {
-          xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
+          xmlChar *tmp = xmlNodeListGetString (doc, cur->children, 1);
           if (tmp)
             {
               gchar *curname = g_strdup_printf ("DenemoPref_%s", cur->name);
@@ -280,7 +280,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
       READXMLENTRY (browser)
       else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "autosavetimeout"))
         {
-          xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
+          xmlChar *tmp = xmlNodeListGetString (doc, cur->children, 1);
           if (tmp)
             {
               gchar *curname = g_strdup_printf ("DenemoPref_%s", cur->name);
@@ -295,7 +295,7 @@ parseConfig (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
         }
       else if (0 == xmlStrcmp (cur->name, (const xmlChar *) "maxhistory"))
         {
-          xmlChar *tmp = xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
+          xmlChar *tmp = xmlNodeListGetString (doc, cur->children, 1);
           if (tmp)
             {
               gchar *curname = g_strdup_printf ("DenemoPref_%s", cur->name);
@@ -543,7 +543,7 @@ writeHistoryEntry (gpointer data, gpointer user_data)
 static void
 parseHistory (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
 {
-  cur = cur->xmlChildrenNode;
+  cur = cur->children;
   while (cur != NULL)
     {
       if (xmlStrcmp (cur->name, (const xmlChar *) "file") == 0)
@@ -551,7 +551,7 @@ parseHistory (xmlDocPtr doc, xmlNodePtr cur, DenemoPrefs * prefs)
           gsize read = 0, written = 0;
           GError *err = NULL;
           gchar *tmp = NULL;
-          tmp = (gchar *) xmlNodeListGetString (doc, cur->xmlChildrenNode, 1);
+          tmp = (gchar *) xmlNodeListGetString (doc, cur->children, 1);
           if (tmp)
             {
               gchar *file = g_filename_to_utf8 (tmp, -1, &read, &written, &err);
@@ -640,7 +640,7 @@ readxmlprefs (gchar * xmlsource, gboolean from_file)
       xmlFreeDoc (doc);
       return ret;
     }
-  rootElem = rootElem->xmlChildrenNode;
+  rootElem = rootElem->children;
   while (rootElem != NULL)
     {
       g_debug ("RootElem 2 %s\n", rootElem->name);
@@ -906,7 +906,7 @@ readHistory ()
       xmlFreeDoc (doc);
       return ret;
     }
-  rootElem = rootElem->xmlChildrenNode;
+  rootElem = rootElem->children;
   //g_message("Reading history file %s", history);
   while (rootElem != NULL)
     {
