@@ -76,6 +76,8 @@ void drawlargetext_cr (cairo_t * cr, const char *text, double x, double y);
 
 void drawtext_cr (cairo_t * cr, const char *text, double x, double y, double size);
 
+void general_draw_text (cairo_t * cr, const char *font, const char *text, double x, double y);
+
 void draw_staff_brace (cairo_t * cr, gboolean curly, gint x, gint y, gint height);
 
 gint draw_for_directives (cairo_t * cr, GList * directives, gint x, gint y, gboolean at_cursor);
@@ -139,7 +141,7 @@ const gchar *get_system_font_dir (void);
 const gchar *get_executable_dir (void);
 /* get directory of current Denemo.project or home directory if untitled. User must free the returned string */
 gchar *get_project_dir (void);
-const gchar *get_local_dir (DenemoDirectory dir);
+gchar *get_local_dir (DenemoDirectory dir);
 gchar *get_system_dir (DenemoDirectory dir);
 
 void copy_files (gchar *source_dir, gchar *dest_dir);//copies all files in source_dir to dest_dir creating the latter if need be
