@@ -16,6 +16,7 @@
 #define TENOR_TOPOFFSET 10
 #define SOPRANO_TOPOFFSET 40
 #define FRENCH_TOPOFFSET 40
+#define BARITONE_TOPOFFSET 0
 
 /**
  * This function draws the clef appropriate for the current context
@@ -26,9 +27,9 @@ draw_clef (cairo_t * cr, gint xx, gint y, clef * clef)
 {
   gint type = clef->type;
   static gint clefoffsets[NUMCLEFTYPES] = { TREBLE_TOPOFFSET, BASS_TOPOFFSET, ALTO_TOPOFFSET, G_8_TOPOFFSET,
-    TENOR_TOPOFFSET, SOPRANO_TOPOFFSET, BASS_TOPOFFSET, FRENCH_TOPOFFSET
+    TENOR_TOPOFFSET, SOPRANO_TOPOFFSET, BASS_TOPOFFSET, FRENCH_TOPOFFSET, BARITONE_TOPOFFSET
   };
-  static gunichar clef_char[NUMCLEFTYPES] = { 0xc9, 0xc7, 0xc5, 0xc9, 0xc5, 0xc5, 0xc7, 0xc9
+  static gunichar clef_char[NUMCLEFTYPES] = { 0xc9, 0xc7, 0xc5, 0xc9, 0xc5, 0xc5, 0xc7, 0xc9, 0xc5
   };
 
   gint override = 0;
@@ -46,7 +47,12 @@ draw_clef (cairo_t * cr, gint xx, gint y, clef * clef)
             }
           if (directive->graphic)
             {
+#ifdef G_OS_WIN32
+              y-= 4; // bizarrely clefs are drawn slightly too low using the windows routine windows_draw_text() in utils.c while standalone and notehead overrides need +4
               drawbitmapinverse_cr (cr, directive->graphic, xx + directive->gx + count, y + directive->gy, FALSE);
+#else              
+              drawbitmapinverse_cr (cr, directive->graphic, xx + directive->gx + count, y + directive->gy, FALSE);
+#endif
             }
         }
     }
