@@ -25,6 +25,7 @@
 #include "core/exportxml.h"
 #include "export/exportmidi.h"
 #include "core/importxml.h"
+#include "export/exportmusicxml.h"
 #include "export/importmusicxml.h"
 #include "importmidi.h"
 
@@ -83,7 +84,7 @@ static struct FileFormatData supported_file_formats[] = {
   {"*.abc",    N_("ABC (*.abc)"),                   ".abc", 0},
   {"*.mid",    N_("Midi (*.mid, *.midi)"),          ".mid", 0},
   {"*.sco",    N_("CSound Score File (*.sco)"),     ".sco", 0},
-  {"*.mxml",   N_("MusicXML file (*.mxml, *.xml)"), ".mxml", 0}
+  {"*.xml",   N_("MusicXML file (*.musicxml, *.mxml, *.xml)"), ".xml", 0}
 };
 
 static GList*
@@ -109,9 +110,10 @@ supported_file_extensions(gchar* format){
   }
 
   if(g_strcmp0 ("musicxml", format) == 0){
+    exts = g_list_append(exts, "*.xml");	  
+    exts = g_list_append(exts, "*.musicxml");
     exts = g_list_append(exts, "*.mxml");
     exts = g_list_append(exts, "*.MXML");
-    exts = g_list_append(exts, "*.xml");
   }
 
   if(g_strcmp0 ("pdf", format) == 0){
@@ -431,7 +433,7 @@ open_for_real (gchar * filename, DenemoProject * gui, DenemoSaveType template, I
         }
       else if (has_extension (filename, ".ly"))
         result = lyinput (filename);
-      else if (has_extension (filename, ".mxml") || has_extension (filename, ".xml"))
+      else if (has_extension (filename, ".mxml") || has_extension (filename, ".xml") || has_extension (filename, ".musicxml"))
         result = mxmlinput (filename);
       else if (has_extension (filename, ".mid") || has_extension (filename, ".midi"))
         result = (type==GUIDED_IMPORT)?guidedImportMidi (filename):importMidi (filename);
@@ -594,6 +596,7 @@ strip_filename_ext (const gchar * file_name, gint format_id)
 /* Save gui in the file in format format_id to the file filename (or gui->filename
    if filename is NULL)
    If there is a scheme script, offers to save that with the file.
+   * for denemo and musicXML returns 0 on success FIXME others should report too?
  */
 static gint
 save_in_format (gint format_id, DenemoProject * gui, gchar * filename)
@@ -618,7 +621,12 @@ save_in_format (gint format_id, DenemoProject * gui, gchar * filename)
               deleteSchemeText ();
               gui->has_script = FALSE;
             }
-        ret = exportXML (file, gui);
+        ret = exportXML (file, gui);// returns 0 on success
+        break;
+      };
+    case MUSICXML_FORMAT:
+      {
+        ret = exportmusicXML (file, gui);// returns 0 on success
         break;
       };
     case MUDELA_FORMAT:
@@ -658,6 +666,7 @@ save_in_format (gint format_id, DenemoProject * gui, gchar * filename)
 /**
  * File save called by fileselsave callback
  * param file_name is full path to file possibly with extension
+ *  returns 0 on success (some formats always return 0)
  */
 static gint
 filesel_save (DenemoProject * gui, const gchar * file_name, gint format_id, DenemoSaveType template)
@@ -1098,7 +1107,7 @@ file_saveaswrapper (DenemoAction * action, DenemoScriptParam * param)
     }
   else
     {
-      gint status = filesel_save (gui, filename, DENEMO_FORMAT, FALSE);
+      gint status = filesel_save (gui, filename, DENEMO_FORMAT, FALSE);// returns 0 on success !not all formats
 
       if(!Denemo.non_interactive){
         if (status == 0)
@@ -1504,7 +1513,15 @@ export_mudela_action (DenemoAction * action, DenemoScriptParam * param)
 {
   export_interface (action, param, MUDELA_FORMAT);
 }
-
+/**
+ * Export musicxml callback prompts for filename
+ *
+ */
+void
+export_musicxml_action (DenemoAction * action, DenemoScriptParam * param)
+{
+  export_interface (action, param, MUSICXML_FORMAT);
+}
 /**
  * Export pdf callback prompts for filename
  *
