@@ -164,6 +164,7 @@ SCM scheme_set_prevailing_keysig (SCM);
 SCM scheme_increment_initial_keysig (SCM);
 SCM scheme_increment_keysig (SCM);
 SCM scheme_add_movement (SCM);
+SCM scheme_toggle_sketch (void);
 SCM scheme_change_chord_notes (SCM);
 SCM scheme_put_note_name (SCM);
 SCM scheme_set_accidental (SCM);
@@ -173,6 +174,7 @@ SCM scheme_insert_note_in_chord (SCM);
 SCM scheme_diatonic_shift (SCM);
 SCM scheme_next_object (void);
 SCM scheme_prev_object (void);
+SCM scheme_next_editable_note (void);
 SCM scheme_next_object_in_measure (void);
 SCM scheme_is_measure_end (void);
 SCM scheme_prev_object_in_measure (void);
@@ -313,6 +315,7 @@ SCM scheme_get_midi_off_time (void);
 SCM scheme_midi_in_append_edit (void);
 SCM scheme_midi_in_checking (void);
 SCM scheme_midi_in_listening (void);
+SCM scheme_toggle_midi_in_listening (void);
 SCM scheme_set_playback_interval (SCM start, SCM end);
 SCM scheme_adjust_playback_start (SCM);
 SCM scheme_adjust_playback_end (SCM);
@@ -396,6 +399,7 @@ SCM scheme_get_lily_version (SCM);
 SCM scheme_check_lily_version (SCM);
 SCM scheme_input_filter_names (SCM);
 SCM scheme_write_status (SCM);
+SCM scheme_is_interactive (void);
 
 SCM scheme_object_directive_get_tag (SCM);
 SCM scheme_standalone_directive_get_tag (SCM);
