@@ -96,7 +96,7 @@ void repack_palette (DenemoPalette *pal)
     }
     gtk_widget_destroy (pal->box);
     pal->box = gtk_grid_new();
-    set_background_color (pal->box, "#8080fe");
+    set_background_color (pal->box, "#8080a0");
    // gchar *tooltip = g_strdup_printf("The \"%s\" Palette:\n%s", pal->name, _("To edit this palette, dock/undock, hide etc, right click on a button and choose Edit Palette."));
    // gtk_widget_set_tooltip_text (pal->box, tooltip);
    // g_free(tooltip);
