@@ -18,6 +18,7 @@
 #include <dirent.h>
 #include <denemo/denemo.h>
 #include "core/prefops.h"
+#include "export/print.h"
 #include "core/utils.h"
 #include "audio/playback.h"
 #include "audio/fluid.h"
@@ -116,7 +117,6 @@ struct callbackdata
 #endif
 #ifdef _HAVE_PORTMIDI_
   GtkWidget *portmidi_input_device;
-  GtkWidget *portmidi_output_device;
 #endif
 #ifdef _HAVE_FLUIDSYNTH_
   GtkWidget *fluidsynth_soundfont;
@@ -222,6 +222,17 @@ set_preferences (struct callbackdata *cbdata)
     (gchar *) gtk_combo_box_text_get_active_text (GTK_COMBO_BOX_TEXT(cbdata->field)));
 
   ASSIGNTEXT (lilypath)
+  
+  Denemo.lilypond_installed_version = get_lily_version_string ();
+  if ((!Denemo.non_interactive) && (Denemo.lilypond_installed_version == NULL))
+	{
+		gchar *msg = g_strdup_printf (_("The LilyPond executable program %s was not found - no typesetting will be possible"), prefs->lilypath->str);
+		warningdialog (msg);
+		g_free (msg);
+	}
+  Denemo.lilypond_include_dir = get_lilypond_include_dir (); 
+  initialize_lilypond_includes();
+  
   ASSIGNTEXT (browser)
   ASSIGNTEXT (imageviewer)
   ASSIGNTEXT (graphicseditor)
@@ -265,7 +276,6 @@ set_preferences (struct callbackdata *cbdata)
 #endif
 #ifdef _HAVE_PORTMIDI_
     ASSIGNCOMBO (portmidi_input_device)
-    ASSIGNCOMBO (portmidi_output_device)
 #endif
 #ifdef _HAVE_FLUIDSYNTH_
     ASSIGNTEXT (fluidsynth_soundfont)
@@ -732,13 +742,7 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
   gtk_box_pack_start (GTK_BOX (main_vbox), portaudio_settings, FALSE, TRUE, 0);
 
   GList *devices = get_portaudio_devices ();
-
-#ifndef G_OS_WIN32
-  /* if default is requested choose first in portaudio list, rather than rely on portaudio which fails to select a default */
-  if ((!strcmp (Denemo.prefs.portaudio_device->str, "default")) && (g_list_length (devices) > 1))
-    g_string_assign (Denemo.prefs.portaudio_device, (gchar *) (devices->next->data));
-#endif
-  COMBOBOX (_("Output device"), portaudio_device, devices, Denemo.prefs.portaudio_device->str, FALSE);
+  COMBOBOX (_("Output device - Advanced Users Only!!"), portaudio_device, devices, Denemo.prefs.portaudio_device->str, FALSE);
   free_portaudio_devices (devices);
 
   INTENTRY_LIMITS (_("Sample rate"), portaudio_sample_rate, 0, 96000);
@@ -796,13 +800,10 @@ preferences_change (GtkAction * action, DenemoScriptParam * param)
   gtk_box_pack_start (GTK_BOX (main_vbox), portmidi_settings, FALSE, TRUE, 0);
 
   GList *input_devices = get_portmidi_devices (FALSE);
-  GList *output_devices = get_portmidi_devices (TRUE);
 
   COMBOBOX (_("Input device"), portmidi_input_device, input_devices, Denemo.prefs.portmidi_input_device->str, FALSE);
-  COMBOBOX (_("Output device"), portmidi_output_device, output_devices, Denemo.prefs.portmidi_output_device->str, FALSE);
 
   free_portmidi_devices (input_devices);
-  free_portmidi_devices (output_devices);
 
 #undef VBOX
 #define VBOX main_vbox
