@@ -295,6 +295,27 @@ set_properties (struct callbackdata *cbdata)
   score_status (cbdata->gui, TRUE);
 }
 
+//Check all staffs for one with same channel but different program as the passed staff and report its number >0 if found, else 0
+static gint check_for_channel_conflicts (DenemoStaff *staffstruct)
+{
+  DenemoProject *gui = Denemo.project;
+  DenemoMovement *si = gui->movement;
+  gint midi_channel = staffstruct->midi_channel;
+  gint midi_prognum = staffstruct->midi_prognum;
+  gint staffnum = 1;
+  GList *curstaff = si->thescore;
+    for (curstaff;curstaff;curstaff=curstaff->next, staffnum++)
+      {
+        DenemoStaff *thisstaff = (DenemoStaff *)curstaff->data;
+        if (thisstaff == staffstruct)
+          continue;
+        if (thisstaff->midi_channel == midi_channel && 
+            thisstaff->midi_prognum != midi_prognum)
+            return staffnum;
+      }
+  return 0;
+}
+
 
 /**
  * Create Dialog to allow the user to set the current staff's parameters
@@ -463,6 +484,7 @@ staff_properties_change (void)
   // BOOLEANENTRY("Override MIDI Channel/Program", midi_prognum_override);
   INTENTRY_LIMITS_1 (_("Channel:"), midi_channel, 1, 16);
   INTENTRY_LIMITS_1 (_("Program:"), midi_prognum, 1, 128);
+  gtk_widget_set_sensitive (midi_prognum, !staffstruct->midi_instrument->len); // meaningless to set prognum if instrument name is set
  // g_debug ("chan prog %d %d\n", staffstruct->midi_channel, staffstruct->midi_prognum);
 
   // FIXME
@@ -502,7 +524,12 @@ staff_properties_change (void)
       result = TRUE;
     }
   gtk_widget_destroy (dialog);
-
+  gint conflict_staff = check_for_channel_conflicts (staffstruct);
+  if (conflict_staff)
+    { gchar *msg = g_strdup_printf ("%s%d%s", _("Staff "), conflict_staff, _(" is using the same MIDI channel as this staff, but a different MIDI instrument - this won't work. Choose a different channel."));
+      warningdialog (msg);
+      g_free (msg);
+    }
   return result;
 }
 
